Module delete_nth

Module delete_nth 

The delete_nth algorithm

Functions

delete_nth
Returns a list where no more than n occurence can be in the output, HashSet version.
delete_nth_naive
Returns a list where no more than n occurence can be in the output, naive version.