is_isomorphic

Function is_isomorphic 

pub fn is_isomorphic(s: &str, t: &str) -> bool
Check if two strings are isomorphic.

Takes two string slices an returns true or false based on whether they are isomorphic or not.

Examples

Basic usage:

assert!(algorithmz::map::is_isomorphic("egg", "add"));

Another example:

assert!(!algorithmz::map::is_isomorphic("foo", "bar"));