ZigZagIterator

Struct ZigZagIterator 

pub struct ZigZagIterator { /* private fields */ }
Zigzag Iterator

Interleave elements from two lists in a zigzag fashion. Elements are yielded alternately from each list until both are exhausted.

Examples

Basic usage:

let mut it = algorithmz::queue::ZigZagIterator::new(vec![1,2],vec![3,4,5]);
while it.has_next() {
    println!("{}",it.next().unwrap());
}

Implementations

Source

impl ZigZagIterator

pub fn new(v1: Vec<i32>, v2: Vec<i32>) -> Self

new iterator constructor

pub fn next(&mut self) -> Option<i32>

grab the next item

pub fn has_next(&self) -> bool

is there a next element?