The delete_nth algorithm
Functions
- delete_
nth - Returns a list where no more than n occurence can be in the output, HashSet version.
- delete_
nth_ naive - Returns a list where no more than n occurence can be in the output, naive version.