pub struct ZigZagIterator { /* private fields */ }Expand description
Zigzag Iterator
Interleave elements from two lists in a zigzag fashion. Elements are yielded alternately from each list until both are exhausted.
Examples
Basic usage:
let mut it = algorithmz::queue::ZigZagIterator::new(vec![1,2],vec![3,4,5]);
while it.has_next() {
println!("{}",it.next().unwrap());
}Implementations